@@ -19,7 +19,7 @@ r"""
 Blacklist various Python calls known to be dangerous
 ====================================================
 
-This balcklist data checks for a number of Python calls known to have possible
+This blacklist data checks for a number of Python calls known to have possible
 security implications. The following blacklist tests are run against any
 function calls encoutered in the scanned code base, triggered by encoutering
 ast.Call nodes.
@@ -124,7 +124,7 @@ be reviewed.
 +------+---------------------+------------------------------------+-----------+
 | ID   |  Name               |  Calls                             |  Severity |
 +======+=====================+====================================+===========+
-| B308 | mark_safe           | - mark_safe                        | Medium    |
+| B308 | mark_safe           | - django.utils.safestring.mark_safe| Medium    |
 +------+---------------------+------------------------------------+-----------+
 
 B309: httpsconnection
@@ -136,8 +136,7 @@ https://wiki.openstack.org/wiki/OSSN/OSSN-0033
 +------+---------------------+------------------------------------+-----------+
 | ID   |  Name               |  Calls                             |  Severity |
 +======+=====================+====================================+===========+
-| B309 | httpsconnection     | - mark_safe                        | Medium    |
-|      |                     | - httplib.HTTPSConnection          |           |
+| B309 | httpsconnection     | - httplib.HTTPSConnection          | Medium    |
 |      |                     | - http.client.HTTPSConnection      |           |
 |      |                     | - six.moves.http_client            |           |
 |      |                     |   .HTTPSConnection                 |           |
@@ -191,7 +190,7 @@ purposes.
 B312: telnetlib
 ---------------
 
-Telnet-related funtions are being called. Telnet is considered insecure. Use
+Telnet-related functions are being called. Telnet is considered insecure. Use
 SSH or some other encrypted protocol.
 
 +------+---------------------+------------------------------------+-----------+
@@ -251,7 +250,7 @@ to XML attacks. Methods should be replaced with their defusedxml equivalents.
 B321: ftplib
 ------------
 
-FTP-related funtions are being called. FTP is considered insecure. Use
+FTP-related functions are being called. FTP is considered insecure. Use
 SSH/SFTP/SCP or some other encrypted protocol.
 
 +------+---------------------+------------------------------------+-----------+
@@ -260,6 +259,20 @@ SSH/SFTP/SCP or some other encrypted protocol.
 | B321 | ftplib              | - ftplib.\*                        | High      |
 +------+---------------------+------------------------------------+-----------+
 
+B322: input
+------------
+
+The input method in Python 2 will read from standard input, evaluate and
+run the resulting string as python source code. This is similar, though in
+many ways worse, then using eval. On Python 2, use raw_input instead, input
+is safe in Python 3.
+
++------+---------------------+------------------------------------+-----------+
+| ID   |  Name               |  Calls                             |  Severity |
++======+=====================+====================================+===========+
+| B322 | input               | - input                            | High      |
++------+---------------------+------------------------------------+-----------+
+
 """
 
 from bandit.blacklists import utils
@@ -337,7 +350,7 @@ def gen_blacklist():
         ))
 
     sets.append(utils.build_conf_dict(
-        'mark_safe', 'B308', ['mark_safe'],
+        'mark_safe', 'B308', ['django.utils.safestring.mark_safe'],
         'Use of mark_safe() may expose cross-site scripting '
         'vulnerabilities and should be reviewed.'
         ))
@@ -386,7 +399,7 @@ def gen_blacklist():
 
     sets.append(utils.build_conf_dict(
         'telnetlib', 'B312', ['telnetlib.*'],
-        'Telnet-related funtions are being called. Telnet is considered '
+        'Telnet-related functions are being called. Telnet is considered '
         'insecure. Use SSH or some other encrypted protocol.',
         'HIGH'
         ))
@@ -396,7 +409,8 @@ def gen_blacklist():
 
     xml_msg = ('Using {name} to parse untrusted XML data is known to be '
                'vulnerable to XML attacks. Replace {name} with its '
-               'defusedxml equivalent function.')
+               'defusedxml equivalent function or make sure '
+               'defusedxml.defuse_stdlib() is called')
 
     sets.append(utils.build_conf_dict(
         'xml_bad_cElementTree', 'B313',
@@ -458,16 +472,27 @@ def gen_blacklist():
          'lxml.etree.GlobalParserTLS',
          'lxml.etree.getDefaultParser',
          'lxml.etree.check_docinfo'],
-        xml_msg
+        ('Using {name} to parse untrusted XML data is known to be '
+         'vulnerable to XML attacks. Replace {name} with its '
+         'defusedxml equivalent function.')
         ))
 
     # end of XML tests
 
     sets.append(utils.build_conf_dict(
         'ftplib', 'B321', ['ftplib.*'],
-        'FTP-related funtions are being called. FTP is considered '
+        'FTP-related functions are being called. FTP is considered '
         'insecure. Use SSH/SFTP/SCP or some other encrypted protocol.',
         'HIGH'
         ))
 
+    sets.append(utils.build_conf_dict(
+        'input', 'B322', ['input'],
+        'The input method in Python 2 will read from standard input, '
+        'evaluate and run the resulting string as python source code. This '
+        'is similar, though in many ways worse, then using eval. On Python '
+        '2, use raw_input instead, input is safe in Python 3.',
+        'HIGH'
+        ))
+
     return {'Call': sets}
